utils::globalVariables(c("k","v","n","dta","tvals"))
#' cfa: A package for computing counterfactuals with a continuous treatment
#'
#' @docType package
#' @name cfa
#' @import stats
#' @import ggplot2
#' @import utils
#' @import BMisc
#' @import quantreg
#' @import TempleMetrics
#' @import pbapply
#' @importFrom formula.tools lhs
NULL
